@@ -2,7 +2,12 @@ from sqlalchemy import (Column, Integer, String, ForeignKey, Enum)
 from sqlalchemy.orm import relationship
 
 from .base_model import BaseModel
-from ..schemas.files_schema import AccessFilesRules
+
+
+class AccessFilesRules(Enum):
+    internal = "internal"
+    public = "public"
+    private = "private"
 
 
 class NextcloudFiles(BaseModel):
